@@ -5,7 +5,7 @@
 $::PROTOCOL = '(?:s?https?|ftp)';
 $::RXURL    = '(?:s?https?|ftp)://[-\\w.!~*\'();/?:@&=+$,%#]+' ;
 $::charset  = 'EUC-JP';
-$::version  = '1.1.9_0';
+$::version  = '1.1.9_1';
 %::form     = %::forms = ();
 $::me       = $::postme = $ENV{SCRIPT_NAME};
 $::print    = ' 'x 10000; $::print = '';
@@ -1032,7 +1032,19 @@ sub print_page{
         { depth => -1 , text  => $title , title => $title , sharp => '' }
     );
 
-    my %attachment=map{ &enc($_)=>1 } &list_attachment($title);
+    my %attachment;
+    foreach my $attach ( &list_attachment($title) ){
+        my $e_attach = &enc( $attach );
+        my $url=&attach2url($title,$attach);
+        $attachment{ $e_attach } = {
+            # for compatible #
+            name => $attach ,
+            url  => $url ,
+            tag  => $attach =~ /\.(png|gif|jpg|jpeg)$/i
+                    ? qq(<img src="${url}" alt="${e_attach}">)
+                    : qq(<a href="${url}" title="${e_attach}">${e_attach}</a>) ,
+        };
+    }
     my %session=(
         title      => $title ,
         attachment => \%attachment ,
